# chanctrl.tcl for netbots.tcl v3.15
# designed to work with eggdrop 1.5.2 or higher
# Johoho's Eggdrop Page - http://johoho.eggdrop.cx
# chanctrl.tcl copyright (c) 1999,2000 by johoho <johoho@hojo-net.de>
# netbots.tcl copyright (c) 1998-2000 by slennox <slennox@egghelp.org>

## chanctrl.tcl component script v1.51.0, 18.03.2000 ##

# History:
# 
# v1.00.0, 01.02.2000 - initial release
# v1.50.0, 03.02.2000 - added quit msg check
# v1.51.0, 17.03.2000 - fixed wrong bans and quit msg check procedures

# Todo:
# 
# - add a check for /part msg colours
# - add caps support
# - add a command for changing color status manually (?)
# - unify code, so I don't need to write extra proc for each color task

# thanks to dw and NML_375 for help. thanks slennox for netbots.tcl

# chan check proc
proc cc_cc {chan} {
global cc_chans
  foreach tmp [split $cc_chans] {
    if {$tmp == $chan} {
      return 1
    }
  }
}

# color check proc
proc cc_check {text} {
  if {[regexp \[\003\] $text]} { 
    return 1
  } else {
    return 0
  }
}

proc cc_public {nick uhost hand chan text} {
global cc_chans cc_flag cc_note cc_note_cfirst cc_note_clevel1 cc_note_clevel2 cc_note_clevel3
  if {[matchattr $hand $cc_flag|$cc_flag $chan]} { 
    return 0
  }
  if {$cc_chans == ""} {
    set cc_chans [channels]
  }
  if {(![botisop $chan]) || (![cc_cc $chan])} { 
    return 0
  }
  if {[cc_check $text]} {

    # check if user is on level 3 (it's over - permanently banned)
    if {[getuser $hand xtra chan_color] == "3"} {
      foreach msg $cc_note_clevel3 {
        puthelp "PRIVMSG $nick :$msg"
      }
      putkick $chan $nick "Color Abuse - banned"
      set i 0
      foreach hmask [getuser $hand hosts] {
        newchanban $chan [maskhost $hmask] ChanCtrl "Color Abuse - [ctime [unixtime]]" 0
        incr i
      }
      putlog "ChanCtrl: $nick used colors in $chan. Staying on level 4 and banning him"
      foreach recipient $cc_note {
        if {[validuser $recipient]} {
          sendnote ChanCtrl $recipient "$nick was banned with $i hostmask permanently on $chan due to color abuse"
        }
      }
      unset i
      return 1
    } elseif {[getuser $hand xtra chan_color] == "2"} {

    # check if user is on level 2 (warning ban - banned for two days)
      foreach msg $cc_note_clevel2 {
        puthelp "PRIVMSG $nick :$msg"
      }
      putkick $chan $nick "Color Abuse - banned for two days"
      set i 0
      foreach hmask [getuser $hand hosts] {
        newchanban $chan [maskhost $hmask] ChanCtrl "Color Abuse - [ctime [unixtime]]" 2880
        incr i
      }
      setuser $nick xtra chan_color "3"
      putlog "ChanCtrl: $nick used colors in $chan. Raising status to level 3"
      foreach recipient $cc_note {
        if {[validuser $recipient]} {
          sendnote ChanCtrl $recipient "$nick was banned with $i hostmask for 2 days due to color abuse"
        }
      }
      unset i
      return 1
    } elseif {[getuser $hand xtra chan_color] == "1"} {

    # check if user is on level 1 (second warning - kick)
      foreach msg $cc_note_clevel1 {
        puthelp "PRIVMSG $nick :$msg"
      }
      putkick $chan $nick "Color Abuse"
      setuser $nick xtra chan_color "2"
      putlog "ColorCtrl: $nick used colors in $chan. Raising status to level 2"
      return 1
    } else {

    # no record yet (first warning - no action)
      foreach msg $cc_note_cfirst {
        puthelp "PRIVMSG $nick :$msg"
      }
      if {![validuser $nick]} {
        putlog "ChanCtrl: adduser $nick with [maskhost $uhost]"
        adduser $nick [maskhost $uhost]
      }
      setuser $nick xtra chan_color "1"
      putlog "ChanCtrl: $nick has used colors in $chan. Raising status to level 1."
      return 1
    }   
  }
}


proc cc_quit {nick uhost hand chan reason} {
global cc_chans cc_flag cc_note cc_note_qfirst cc_note_qlevel1 cc_note_qlevel2 cc_note_qlevel3
  if {[matchattr $hand $cc_flag|$cc_flag $chan]} { 
    return 0
  }
  if {$cc_chans == ""} {
    set cc_chans [channels]
  }
  if {![cc_cc $chan]} { 
    return 0
  }
  if {[cc_check $reason]} {
    if {[getuser $hand xtra quit_color] == "3"} {

    # fourth abuse (no more warnings - banned for two days)
      set i 0
      foreach hmask [getuser $hand hosts] {
        newchanban $chan [maskhost $hmask] ChanCtrl "Color Abuse - [ctime [unixtime]]" 0
        incr i
      }
      sendnote ChanCtrl $nick $cc_note_qlevel1
      foreach recipient $cc_note {
        if {[validuser $recipient]} {
          sendnote ChanCtrl $recipient "$nick was banned with $i hostmask due to color abuse"
        }
      }
      unset i
      setuser $nick xtra quit_color "3"
      putlog "ChanCtrl: $nick has used colors in his quit msg. Raising status to level 3."
      return 1
    } elseif {[getuser $hand xtra quit_color] == "2"} {

    # third abuse (last warning - banned for two days)
      set i 0
      foreach hmask [getuser $hand hosts] {
        newchanban $chan [maskhost $hmask] ChanCtrl "Color Abuse - [ctime [unixtime]]" 2880
        incr i
      }
      sendnote ChanCtrl $nick $cc_note_qlevel1
      foreach recipient $cc_note {
        if {[validuser $recipient]} {
          sendnote ChanCtrl $recipient "$nick was banned with $i hostmask for 2 days due to color abuse"
        }
      }
      unset i
      setuser $nick xtra quit_color "3"
      putlog "ChanCtrl: $nick has used colors in his quit msg. Raising status to level 3."
      return 1
    } elseif {[getuser $hand xtra quit_color] == "1"} {

    # second abuse (secord warning - no action)
      sendnote ChanCtrl $nick $cc_note_qlevel1
      setuser $nick xtra quit_color "2"
      putlog "ChanCtrl: $nick has used colors in his quit msg. Raising status to level 2."
      return 1
    } else {

    # no record yet (first warning - no action)
      if {![validuser $nick]} {
        putlog "ChanCtrl: adduser $nick with [maskhost $uhost]"
        adduser $nick [maskhost $uhost]
      }
      sendnote ChanCtrl $nick $cc_note_qfirst
      setuser $hand xtra quit_color "1"
      putlog "ChanCtrl: $nick has used colors in his quit msg. Raising status to level 1."
      return 1
    }
  }  
}


bind pubm - * cc_public
if {!$cc_chan} {
  unbind pubm - * cc_public
}

bind sign - * cc_quit
if {!$cc_quit} {
  unbind sign - * cc_quit
}
